@@ -55,6 +55,7 @@ def list_directory(entry: str, addr: int) -> None:
     opt, path = entry.split(';')
     path = path.removeprefix('Microsoft.PowerShell.Core\\FileSystem::')
 
+    # Ls class can handle symlink
     ls = Ls(opt, path, to_cache=True)
     ls.echo(0)
 
@@ -72,6 +73,7 @@ def scan(entry, addr):  # Basically, main
 
     # Wsl
     curdir = curdir.removeprefix('Microsoft.PowerShell.Core\\FileSystem::')
+    curdir = os.path.realpath(curdir)  # handle symlink
 
     brackets = []
     after_brackets = []
